Index: src/arm/stub-cache-arm.cc |
diff --git a/src/arm/stub-cache-arm.cc b/src/arm/stub-cache-arm.cc |
index 215de73ec4143416f0a22c3eb5a0b22e8955b696..c905a8a82cd7e56fd9186e866793369b6a7cfbc1 100644 |
--- a/src/arm/stub-cache-arm.cc |
+++ b/src/arm/stub-cache-arm.cc |
@@ -130,14 +130,14 @@ static void ProbeTable(Isolate* isolate, |
// the property. This function may return false negatives, so miss_label |
// must always call a backup property check that is complete. |
// This function is safe to call if the receiver has fast properties. |
// Name must be a symbol and receiver must be a heap object. |
static void GenerateDictionaryNegativeLookup(MacroAssembler* masm, |
Label* miss_label, |
Register receiver, |
Handle<String> name, |
Register scratch0, |
Register scratch1) { |
- ASSERT(name->IsSymbol()); |
+ ASSERT(name->IsInternalizedString()); |
Counters* counters = masm->isolate()->counters(); |
__ IncrementCounter(counters->negative_lookups(), 1, scratch0, scratch1); |
__ IncrementCounter(counters->negative_lookups_miss(), 1, scratch0, scratch1); |
@@ -1102,8 +1102,8 @@ Register StubCompiler::CheckPrototypes(Handle<JSObject> object, |
if (!current->HasFastProperties() && |
!current->IsJSGlobalObject() && |
!current->IsJSGlobalProxy()) { |
- if (!name->IsSymbol()) { |
- name = factory()->LookupSymbol(name); |
+ if (!name->IsInternalizedString()) { |
+ name = factory()->InternalizeString(name); |
} |
ASSERT(current->property_dictionary()->FindEntry(*name) == |
StringDictionary::kNotFound); |
@@ -2052,7 +2052,7 @@ Handle<Code> CallStubCompiler::CompileStringCharAtCall( |
if (index_out_of_range.is_linked()) { |
__ bind(&index_out_of_range); |
- __ LoadRoot(r0, Heap::kEmptyStringRootIndex); |
+ __ LoadRoot(r0, Heap::kempty_stringRootIndex); |
__ Drop(argc + 1); |
__ Ret(); |
} |
@@ -2488,7 +2488,7 @@ Handle<Code> CallStubCompiler::CompileCallConstant(Handle<Object> object, |
case STRING_CHECK: |
if (function->IsBuiltin() || !function->shared()->is_classic_mode()) { |
// Check that the object is a two-byte string or a symbol. |
__ CompareObjectType(r1, r3, r3, FIRST_NONSTRING_TYPE); |
__ b(ge, &miss); |
// Check that the maps starting from the prototype haven't changed. |
@@ -130,14 +130,14 @@ static void ProbeTable(Isolate* isolate, |
// must always call a backup property check that is complete. |
// This function is safe to call if the receiver has fast properties. |
-// Name must be a symbol and receiver must be a heap object. |
+// Name must be internalized and receiver must be a heap object. |
static void GenerateDictionaryNegativeLookup(MacroAssembler* masm, |
Label* miss_label, |
@@ -2488,7 +2488,7 @@ Handle<Code> CallStubCompiler::CompileCallConstant(Handle<Object> object, |
case STRING_CHECK: |
if (function->IsBuiltin() || !function->shared()->is_classic_mode()) { |
- // Check that the object is a two-byte string or a symbol. |
+ // Check that the object is a two-byte string (internalized or not). |
__ CompareObjectType(r1, r3, r3, FIRST_NONSTRING_TYPE); |
__ b(ge, &miss); |